@@ -1,7 +1,13 @@
 import os, sys, platform
 
+WIN = False
+LINUX = False
+
 if platform.system() == "Windows":
-	os.system("")
+    WIN = True
+    os.system("")
+else:
+    LINUX = True
 
 class style:
     """
@@ -83,7 +89,15 @@ class style_handler:
         return self.styles_dict.get(key)
 
 
+def getfgfromrgb(r, g, b):
+    return "\033[38;2;" + str(r) + ";" + str(g) + ";" + str(b) + "m"
+
+def getbgfromrgb(r, g, b):
+    return "\033[48;2;" + str(r) + ";" + str(g) + ";" + str(b) + "m"
+
 def cprint(*args, sep=" ", end="\n", file=sys.stdout, flush=False):
+    sep = style.RESET + sep
+
     if len(args) > 1:
         for msg in args:
             msg = str(msg)
@@ -100,8 +114,9 @@ def cprint(*args, sep=" ", end="\n", file=sys.stdout, flush=False):
 def cinput(prompt):
     return input(prompt + style.RESET)
 
+if WIN:
+    def setcmdname(name):
+        cprint("\x1b]0;" + name + "\x07", end="")
+
 def reset():
     print(style.RESET)
-
-
-cprint(1)
